@@ -8,24 +8,42 @@ module Jaeger
     # well, but if requests are bursty, especially sub-second, then a number
     # of sequential requests can be sampled each second.
     class RateLimiting
-      attr_reader :tags
+      attr_reader :tags, :max_traces_per_second
 
       def initialize(max_traces_per_second: 10)
+        update(max_traces_per_second: max_traces_per_second)
+      end
+
+      def update(max_traces_per_second:)
         if max_traces_per_second < 0.0
           raise "max_traces_per_second must not be negative, got #{max_traces_per_second}"
         end
 
-        @rate_limiter = RateLimiter.new(
-          credits_per_second: max_traces_per_second,
-          max_balance: [max_traces_per_second, 1.0].max
-        )
+        return false if max_traces_per_second == @max_traces_per_second
+
         @tags = {
           'sampler.type' => 'ratelimiting',
           'sampler.param' => max_traces_per_second
         }
+        @max_traces_per_second = max_traces_per_second
+        max_balance = [max_traces_per_second, 1.0].max
+
+        if @rate_limiter
+          @rate_limiter.update(
+            credits_per_second: max_traces_per_second,
+            max_balance: max_balance
+          )
+        else
+          @rate_limiter = RateLimiter.new(
+            credits_per_second: max_traces_per_second,
+            max_balance: [max_traces_per_second, 1.0].max
+          )
+        end
+
+        true
       end
 
-      def sample?(*)
+      def sample(*)
         [@rate_limiter.check_credit(1.0), @tags]
       end
     end
