@@ -4,6 +4,7 @@ module Jaeger
   module TraceId
     MAX_64BIT_SIGNED_INT = (1 << 63) - 1
     MAX_64BIT_UNSIGNED_INT = (1 << 64) - 1
+    MAX_128BIT_UNSIGNED_INT = (1 << 128) - 1
     TRACE_ID_UPPER_BOUND = MAX_64BIT_UNSIGNED_INT + 1
 
     def self.generate
@@ -12,8 +13,16 @@ module Jaeger
 
     def self.base16_hex_id_to_uint64(id)
       return nil unless id
+
       value = id.to_i(16)
-      value > MAX_64BIT_UNSIGNED_INT || value < 0 ? 0 : value
+      value > MAX_64BIT_UNSIGNED_INT || value.negative? ? 0 : value
+    end
+
+    def self.base16_hex_id_to_uint128(id)
+      return nil unless id
+
+      value = id.to_i(16)
+      value > MAX_128BIT_UNSIGNED_INT || value.negative? ? 0 : value
     end
 
     # Thrift defines ID fields as i64, which is signed, therefore we convert
